
Session information is not stored serverside
-------

**Description:**

Whenever session information is not stored serverside an attacker could easily tamper 
and manipulate these values.


**Solution:**

Session information should aways be stored serverside by means of a serverside language.

	